# Supplement to Shevnina et al., 2022: Evaporation over glacial lakes
# Authorship: eshevnina@gmail.com
# phone: +358449185446

#################################### DATA #####################################################################################
###############################################################################################################################
########## Meteo parameters and evaporation according to ERA5 at grid node nearest to Novo site
########## contribution by T. Naakka ##############################
#path<-"/home/shevnina/Manuscripts/2021/AntarcticEVA/supplement/evaporation/"
path<-"/home/shevnina/Manuscripts/2022/Antarctica_evaporation/Gryosphere2021/new_supplements/"
setwd(path)
eva_era<-read.csv("Evaporation_Schirmacher_Oasis_from_ERA5.csv", header = F, sep=",", skip=3)             ##### results from ERA
eva_era$ts<-paste(eva_era$V3,eva_era$V2, eva_era$V1, sep="-")
eva_era$TS_UTS<-as.POSIXlt(eva_era$ts, format = "%Y-%m-%d")
eva_era$newTS<-as.Date(eva_era$TS_UTS)

############### FIELD EXPERIMENT ##############################################################################################
########## WATER TEMPERATURE MEASURED BY HOBO sensor: https://doi.org/10.5281/zenodo.3467126 ##################################
########## 30.12.2017 - 08.02.2018 
setwd("/home/shevnina/Manuscripts/2022/Antarctica_evaporation/Gryosphere2021/new_supplements/")
Indat4 <- "wl_parwati.txt"  #### HOBO Water level/temperature sensor
dat4 <- read.table(Indat4,sep=",",skip=2,header=F)                             #### HOBO RAW DATA
dat4 <- dat4[,2:5]
colnam <- c("Timestamp","Abs_Press","TW","WL")
colnames(dat4) <- colnam

# done by Daniela Franz [recreate timestamp, time is am and pm but without saying what is am and pm ==> starts with pm as temp goes down]
timestamp1 <- substr(dat4$Timestamp,1,8)
timestamp2 <- substr(dat4$Timestamp,14,18)
dat4$Timestamp <- paste(timestamp1,timestamp2,sep=" ")
dat4$Timestamp <- as.POSIXct(dat4$Timestamp,tz="Europe/Helsinki",format="%m.%d.%y %H.%M")
dat4$Timestamp <- seq(as.POSIXct(dat4$Timestamp,tz="Europe/Helsinki",format="%Y-%m-%d %H:%M")[1]+12*60*60,
                      as.POSIXct(dat4$Timestamp,tz="Europe/Helsinki",format="%Y-%m-%d %H:%M")[nrow(dat4)]+12*60*60,
                      60*10)
dat4$Timestamp_UTC <- dat4$Timestamp       #original data given in EET, needs to be converted into UTC

########## to calculate the daily mean of water temperature
dat4$one_min<-strptime(dat4$Timestamp_UTC, format="%Y-%m-%d %H:%M:%S")
hobo24hour<- aggregate(list(TW_mean = dat4$TW),list(Timestamp= cut(dat4$one_min, "24 hour" )), mean)
min<-aggregate(list(TW_min = dat4$TW),list(Timestamp= cut(dat4$one_min, "24 hour" )), min)
max<-aggregate(list(TW_max = dat4$TW),list(Timestamp= cut(dat4$one_min, "24 hour" )), max)
hobo24hour$newTS<-as.Date(hobo24hour$Timestamp, "%Y-%m-%d")
hobo24hour$TW_min<-min$TW_min
hobo24hour$TW_max<-max$TW_max
hobo_day<-subset(hobo24hour, hobo24hour$newTS>="2018-01-01" & hobo24hour$newTS<="2018-02-07")  ### subsetting for the period of experiment
########################################################################################################################################

####### Meteorological parameters observed at Maitri site ##############################################################################
####### Contribution by P. Dhote and P. Thakur
path<-"/home/shevnina/Manuscripts/2022/Antarctica_evaporation/Gryosphere2021/new_supplements/"
setwd(path)
meteo_m<-read.csv("MeteoMaitri.csv", header = T, sep=",")
meteo_m$TS<-as.POSIXlt(meteo_m$Date, format = "%m/%d/%Y")
meteo_m$newTS<-as.Date(meteo_m$TS)
meteo_ms<-subset(meteo_m, meteo_m$newTS>="2018-01-01" & meteo_m$newTS<="2018-02-07")  ### sub setting for the period of experiment

#### to transform the wind speed to 2 m
A <- 350000                                                    #### the surface area of lake Zub, m2, Dhote et al., (2021)
z0 <- 0.002                                                    ### the roughness constant, Stull, 2017
h1 <- 6                                                        ### height of the wind sensor in Maitri site, m
h2 <- 2                                                        ### 2 m, needed for the empirical functions, m
wind_coef <- log(h2/z0)/log(h1/z0)

meteo_m$WS_tr <- meteo_m$WS*wind_coef                           ###
meteo_m$SatPre<-0.611*exp((12.27*meteo_m$AT)/(meteo_m$AT + 273.16))
meteo_m$VapPre<-meteo_m$RH*meteo_m$SatPre/100

### forcing for the combination equations ++
meteo_ms<-subset(meteo_m, meteo_m$newTS>="2018-01-01" & meteo_m$newTS<="2018-02-07")  ### subsetting for the period of experiment
meteo_ms$SurWaTemp<-hobo_day$TW_mean
meteo_ms$SurSatPre<-0.611*exp((12.27*meteo_ms$SurWaTemp)/(meteo_ms$SurWaTemp + 273.16))
################################################################################################################

####### iButton water temperature data: https://doi.org/10.5281/zenodo.3467126 ###################################
path<-"/home/shevnina/Manuscripts/2022/Antarctica_evaporation/Gryosphere2021/new_supplements/"
setwd(path)
Indat3 <- "data_termo7.txt"                         ### iButton measurements, resolution 10 minutes
dat3 <- read.table(Indat3,sep="C",header=T)
dat3 <- cbind(row.names(dat3),dat3[1])
colnam <- c("Timestamp","TW")
colnames(dat3) <- colnam

dat3$Timestamp <- as.POSIXct(substr(dat3$Timestamp,1,14),tz="Europe/Helsinki",format="%d.%m.%Y %H:%M")         #original data given in EET, needs to be converted into UTC
dat3$Timestamp_UTC <- dat3$Timestamp
attributes(dat3$Timestamp_UTC)$tzone <- "UTC" 
write.table(dat3,"TW.csv",sep=",",row.names=F,quote=F)
dat3<-read.csv("TW.csv")

##########  TW in °C ###################################################
########## to calculate the daily mean of water temperature
dat3$one_min<-strptime(dat3$Timestamp_UTC, format="%Y-%m-%d %H:%M:%S")
ibut24hour<- aggregate(list(TW_mean = dat3$TW),list(Timestamp= cut(dat3$one_min, "24 hour" )), mean)
min<-aggregate(list(TW_min = dat3$TW),list(Timestamp= cut(dat3$one_min, "24 hour" )), min)
max<-aggregate(list(TW_max = dat3$TW),list(Timestamp= cut(dat3$one_min, "24 hour" )), max)
ibut24hour$newTS<-as.Date(ibut24hour$Timestamp, "%Y-%m-%d")
ibut24hour$TW_min<-min$TW_min
ibut24hour$TW_max<-max$TW_max
####################################################################################################################

#### Meteorological parameters and evaporation after the EC measurements
### contribution by M. Potes #######################################################################################
### the fluxes and evaporation after Potes et al., 2017  ###########################################################
# Date Time, is the time stamp (TS) with the format “yy/mm/dd HH:MM:SS” [1]
# npoints, is number of measurements [2]
# u_starr (m/s), taur Kg(m s^2) are u_star and momentum flux [3], [4]
# Hcr (W/m^2) is a sensible heat flux humidity [5]
# LE_wplr (W/m^2), is a latent heat flux //  J m-2 s-1 [6]
# Evap (L/m^2) is an evaporation by Potes M. ## equal to mm of evaporation [7]
# Fc_wplr (mg/(m^2 s)), Fc_wpl_umol (umol/(m^2 s)), is carbon flux with WPL correction, mg/(m^2 s) and umol/(m^2 s) [8], [9]
# CO2_conc (mg/m^3), CO2_PPM (PPM), CO2_sig_str (arb), are CO2 concentration (two unit) and the Irgason’s signal strength [10], [11]
# H2O_conc (g/m^3), H2O_sig_str (arb), are H2O concentration and the Irgason’s signal strength 
# Temp_amb (C), Amb_Press (kPa), are ambient air temperature and atmospheric pressure
# wind_speed (m/s), wind dir_sonic (degree), are wind speed and direction
# obukhov (m), zeta (arb), rou (m), sigmaw_ustar (arb), are Obuhkov length, stability parameter, roughness
# Xmax (m), XR90 (m), are 90% of footprint (m) and maximum of footprint (m)

# To estimate Evaporation:
# L = 2.5x10 6 J kg water–1 = latent heat of vaporization; //Stull, 2015 p. 108
# m2 = 100 00 cm2
# Kg = 1000 g /ρ =1000 cm3 (ρ, density of water = 1 g/cm3 ) 
#  ET is Latent heat energy divided latent heat of vaporization of water: ET = LE/L = J m-2 s-1 /2.5x10 6 J kg-1 = J m-2 s-1 / 2.5x10 6 J kg-1 = J kg /2.5x10 6 J m2 s 
# Substituting for kg of water and m2 to cm2:  = J 1000 cm3 /2.5 MJ 10000 cm2 s = J cm3 /2.5x10 6 J 10 cm2 s = cm /2.5x10 6 s = mm/2.5x10 6 s = 0.0000004 mm/s
# In 30 minutes, = 1800 * 0.0000004 mm/s =0.00072 mm / 30 min 

###################################### Lake Zub/Priyadarshini 2018 ########################################################
############################################################################################################################################
path<-"/home/shevnina/Manuscripts/2022/Antarctica_evaporation/Gryosphere2021/new_supplements/"
setwd(path)
Irgason<-"ANTSA_EC_2018.txt"
variable_unit <- scan(Irgason, nlines = 1, sep=",", what = character())
dat1 <- read.csv(Irgason, skip = 2, header = FALSE, fill=TRUE)
dat1 <- dat1[,1:24]
colnames(dat1) <- c("TS","npoints","u_star","taur","Hcr","LE_wplr",
                    "Evap","Fc_wplr","Fc_wpl_umol","CO2_conc","CO2_PPM","CO2_sig_str",
                    "H2O_conc","H2O_sig_str","Temp_amb","Amb_Press","wind_speed","wind_dir_sonic",
                    "obukhov","zeta","rou","sigmaw_ustar","Xmax","XR90")


dat1$Timestamp_UTC <- strptime(substr(dat1$TS,1,15),tz="UTC",format="%y/%m/%d %H:%M")    # to create proper UTC Timestamp, values corresponded to the end of time interval
dat1$wind_dir_sonic <- (dat1$wind_dir_sonic+43)%%360                                     #correct for the wrong wind direction: added by Daniela Franz

######################### filtering the fluxes as suggested by Daniela Franz ###############################################
### Flag conc and fluxes: to flag signal strengths lower than 0.7 + wind direction from the land + individually outliers
### and to count the percentage of the filtered data
all <- nrow(dat1[!is.na(dat1$H2O_conc),])    # to account to the percentage of data filtered due to the signal strengths (lower than 0.7)
filt <- nrow(dat1[(!is.na(dat1$H2O_sig_str) & dat1$H2O_sig_str >= 0.7),])
(all-filt)*100/all # 0.11 %

filt <- nrow(dat1[(dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),])            # to wind direction from the land 
(all-filt)*100/all  # 17.8 %

# to account the percentage of the data after the filtering 
# total after the Latent sensible flux and Evaporation
filt <- nrow(dat1[!is.na(dat1$Evap) & dat1$H2O_sig_str >= 0.7 & (dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),])
100-((all-filt)*100/all)
# H 
filt <- nrow(dat1[!is.na(dat1$Hcr) & (dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),])
100-((all-filt)*100/all)

# to calculate the Table XX with the filtering
dat1$H2O_conc_filter <- ifelse(dat1$H2O_sig_str >= 0.7 &
                                 (dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),
                               dat1$H2O_conc,
                               NA)
dat1$LE_filter <- ifelse(dat1$H2O_sig_str >= 0.7 &
                           (dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),
                         dat1$LE_wplr,
                         NA)

dat1$Evap_filter <- ifelse(dat1$H2O_sig_str >= 0.7 &
                             (dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),
                           dat1$Evap,
                           NA)

dat1$H_filter <- ifelse((dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),
                        dat1$Hcr,
                        NA)
dat1$tau_filter <- ifelse((dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),
                          dat1$taur,
                          NA)

dat1$u_star_filter <- ifelse((dat1$wind_dir_sonic >= 105 & dat1$wind_dir_sonic <= 240),
                             dat1$u_star,
                             NA)
####################################################################################################################################
####  daily EC evaporation calculated with NA in the values: used further for the errors estimations:
double1<-dat1$Evap_filter  # by mean
double1[is.na(double1)]<-mean(dat1$Evap_filter, na.rm=T)
dat1$Evap_filter<-double1

evap_ECbyMean<-aggregate(list(Evap=dat1$Evap_filter),list(Timestamp= cut(dat1$Timestamp,"1440 min")), sum, na.rm=T) ### daily sum
evap_ECbyMean$newTS<-as.Date(evap_ECbyMean$Timestamp, "%Y-%m-%d")
# sum(evap_ECbyMedian$Evap) [1] 114.133, the daily evaporation measured // 115.8282

##################################################################################################################################


##### The meteorological variables observed at Irgason site: forcing for the combinnation equations
## ird_day consists of the daily averages for the wind_speed, wind_direction, air_temperature, H2O concentration, fluxes and the evaporation 
## Timestamp        LE[Wm-2]          H[Wm-2]        WS[ms-1]         AT[C]      H2O[g sm-3]        P[PA]
## eva[mm day-1] SpecHumid[Pa]   SatPre[Pa] SatSpecHumid[Pa]       RH[%]   VapPre[Pa]
irg_day <- strptime(dat1$Timestamp_UTC, format="%Y-%m-%d")
irg_day <-aggregate(list(LE = dat1$LE_filter, H = dat1$H_filter, WS = dat1$wind_speed, AT = dat1$Temp_amb, H2O = dat1$H2O_conc_filter, P= dat1$Amb_Press*10),list(Timestamp= cut(dat1$Timestamp,"1440 min")), mean, na.rm=T)         ### Amp_Pres is given in Pa due to dividing by 10  ###

### to calculate the relative humidity from the H2O concentration
### the specific humidity ?g kg-1? #############
R<-287.05                                                                  #############the universal gas constant for a dry air, J kg-1 K-1
irg_day$SpecHumid <- R*irg_day$H2O*(irg_day$AT+273.15)/irg_day$P           ######### specific humidity

#### new RH for Irgason after Hoeltgebaum et al. (2020) 
# to calculate the saturated vapor pressure (Pa) after Teten's formula
b1<- 611.3                                                                  # the coefficients according to Stull, 2017
b2<- 17.2694                                                                # #---#
b3<- 35.86                                                                  # #---#
irg_day$SatPre<-"NA"
irg_day$RH <-"NA"
irg_day$SpecHumid <- "NA"
irg_day$SatPre<-0.611*exp((12.27*irg_day$AT)/(irg_day$AT + 273.16))
irg_day$SpecHumid <- R*irg_day$H2O*0.001*(irg_day$AT+273.15)/622
irg_day$RH<-100*irg_day$SpecHumid/irg_day$SatPre
irg_day$VapPre<-irg_day$RH*irg_day$SatPre/100
irg_day$newTS = as.Date(irg_day$Timestamp, "%Y-%m-%d")
irg_day$Ts<-hobo_day$TW_mean                                                # the surface water temperature by HOBO temperature sensor
irg_day$SurSatPre<-0.611*exp((12.27*irg_day$Ts)/(irg_day$Ts + 273.16))      ## Stull, 2017

irg_day$defSP_kPa<-irg_day$SurSatPre*10-irg_day$SatPre*10                  ##### saturation deficit, kPa, Iragson data
############################################################################################################################


######################################### RESULTS ##########################################################################
############################################################################################################################
## Evaporation, mm day-1 after the EC method M. Potesh, E. Shevnina, D. Franz
eva_day<-evap_ECbyMean                   ################ eva_day consists of the values calculated after various methods
eva_day$eva_ec<-evap_ECbyMean$Evap       ### EC method
rm(evap_ECbyMean)
eva_day$newTS<-as.Date(eva_day$Timestamp, "%Y-%m-%d")

########### Evaporation after the bulk aerodynamic method  ######################################################################
########### contribution by T. Vihma ##########################################################################################
path<-"/home/shevnina/Manuscripts/2022/Antarctica_evaporation/Gryosphere2021/new_supplements/"
setwd(path)
eva_bulk<-read.table("Bulk_method_results_Irgason_input.txt", header = T, sep=" ")  ### Irgason input data
eva_bulk$TS<-dat1$Timestamp_UTC
evap_BA<-aggregate(list(Evap=eva_bulk$E_mm_day),list(Timestamp= cut(eva_bulk$TS,"1440 min")), mean, na.rm=T)
eva_day$eva_BA_irg<-evap_BA$Evap                               ###### Evaporation Bulk aerodynamic, irgason site
rm(evap_BA)

eva_bulk<-read.table("Bulk_method_results_Maitri_input.txt", header = T, sep=" ") ### input data is the measurements at Maitri site, something wront
evap_BA<-aggregate(list(Evap=eva_bulk$V),list(Timestamp= cut(eva_bulk$newTS,"1440 min")), mean, na.rm=T)
eva_day$eva_BA_mai<-evap_BAM$Evap                              ###### Evaporation Bulk aerodynamic, Maitri site site
rm(eva_bulk)
###############################################################################################################################################

########################### Combination equations + Errors #####################################################################
########################### contribution by E. Shevnina
################## es in the empirical formulas calculated after the water temperature measured by Hobo
Sh_coef<-2.909 *A^(-0.05)                                                           ### the coefficent in Shuttleworth
########################### forcing by Maitri site
meteo_ms$def<-(meteo_ms$SurSatPre*10-meteo_ms$SatPre*10)                            ### saturation deficit, hPa => kPa

eva_day$eva_sh_mai<-Sh_coef*meteo_ms$WS_tr*meteo_ms$def/10                             ### Shuttleworth, 1993
eva_day$eva_pe_mai<-0.26*(1+0.54*meteo_ms$WS_tr)*meteo_ms$def                          ### penmann, 1948
eva_day$eva_dp_mai<-0.26*(1+0.86*meteo_ms$WS_tr)*meteo_ms$def                          ### doorenboss and Pruit, 1975
eva_day$eva_od_mai<-0.14*(1+0.76*meteo_ms$WS_tr)*meteo_ms$def                          ### odrova, 1979   

### forcing by irgason site
eva_day$eva_sh_ir<- Sh_coef*irg_day$WS*(irg_day$SurSatPre-irg_day$SatPre)
eva_day$eva_pe_ir<- 0.26*(1+0.54*irg_day$WS)*(irg_day$SurSatPre*10-irg_day$SatPre*10) 
eva_day$eva_od_ir<- 0.14*(1+0.72*irg_day$WS)*(irg_day$SurSatPre*10-irg_day$SatPre*10)
eva_day$eva_dp_ir<- 0.26*(1+0.86*irg_day$WS)*(irg_day$SurSatPre*10-irg_day$SatPre*10)
###############################################################################################################################

### output to the external file, combination_equations_results.csv
write.csv(eva_day,"/home/shevnina/Manuscripts/2022/Antarctica_evaporation/Gryosphere2021/new_supplements/combination_equations_results.csv")
#"","Timestamp","Evap",
#"eva_ec", the evaporation by the method of eddy covariance
#"eva_BA_irg","eva_BA_mai", the evaporation by the bulk-aerodynamic method with using observation at Irgason site and Maitri site (subscripts irg and mai, respectively)
#"eva_sh_mai","eva_pe_mai","eva_dp_mai","eva_od_mai","eva_sh_ir","eva_pe_ir","eva_od_ir","eva_dp_ir",
#"eva_lin","eva_pow", the evaporation by the combination equations a+bw2 and aw2^b
#"newTS" is the date


####### fitting of the  empirical equations : coefficients based on the data collected at Maitri site, daily resolution
meteo_ms$eva_ec<-eva_day$eva_ec                            ### the evaporation, evaluated from the EC measurements
x<-meteo_ms$WS_tr
y<-meteo_ms$eva_ec/meteo_ms$def
y[3]<-NaN                                                  # excluded due to untrusted data collected during the storm, day 1
y[4]<-NaN                                                  # and day2
#plot(x, y, xlab="wind speed, [ms-1]", xlim=c(1,10), ylab="E/(es-e2), [mm day-1]/[Pa]", axes=TRUE, type="p", col="black", pch=16)
#grid()

mod_w1<-lm(formula = y ~ x)                                            ##### a+bw2
coef_w1<-coefficients(mod_w1)
meteo_ms$eva_lin<-(coef_w1[2]*x+coef_w1[1])*meteo_ms$def                    # a+b*w2
eva_day$eva_lin<-meteo_ms$eva_lin
sum(eva_day$eva_lin)
#summary(mod_w1)
#Residuals:
#  Min      1Q  Median      3Q     Max 
#-2.0624 -0.6329 -0.2527  0.2735  6.6836 
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  -0.3312     0.6924  -0.478    0.636    
#x             0.6047     0.1219   4.959 1.94e-05 ***
# Residual standard error: 1.609 on 34 degrees of freedom
#(2 observations deleted due to missingness)
#Multiple R-squared:  0.4197,	Adjusted R-squared:  0.4026 
#F-statistic: 24.59 on 1 and 34 DF,  p-value: 1.942e-05


model <- lm(log(y)~ log(x))                                               ##### aw2^b
coef_emp<-coefficients(model)
meteo_ms$eva_pow<-exp(coef_emp[1])*x^(coef_emp[2])*meteo_ms$def           # a*w2^b
eva_day$eva_pow<-meteo_ms$eva_pow
summary(eva_day$eva_pow)
summary(model)


### testing with the independent data: meteo parameters according to Irgason, water temperature is according to iButton
### 27.01.2018 – 09.02.2018
#########################################################################################################################
subset_irg<-subset(irg_day, irg_day$newTS>="2018-01-27" & irg_day$newTS<="2018-02-07")                             ### sub setting for the period of experiment
subset_ibt<-subset(ibut24hour, ibut24hour$newTS>="2018-01-27" & ibut24hour$newTS<="2018-02-07")                   
subset_ec<-subset(evap_ECbyMean, evap_ECbyMean$newTS>="2018-01-27" & evap_ECbyMean$newTS<="2018-02-07")

subset_ibt$eva_ec<-subset_ec$Evap
subset_ibt$T2<-subset_irg$AT
subset_ibt$SurSatPre<-0.611*exp((12.27*subset_ibt$TW_mean)/(subset_ibt$TW_mean + 273.16))
subset_ibt$SatPre<-0.611*exp((12.27*subset_ibt$T2)/(subset_ibt$T2 + 273.16))
subset_ibt$def<-(subset_ibt$SurSatPre*10-subset_ibt$SatPre*10)                            ### saturation deficit, hPa => kPa

subset_ec$eva_lin<-(coef_w1[2]*subset_irg$WS+coef_w1[1])*subset_ibt$def       
subset_ec$eva_pow<-exp(coef_emp[1])*subset_irg$WS^(coef_emp[2])*subset_ibt$def 

#### errors
mean(sqrt((subset_ec$Evap - subset_ec$eva_lin)^2), na.rm=TRUE)                 ## 1.260201
mean(sqrt((subset_ec$Evap - subset_ec$eva_pow)^2), na.rm=TRUE)                 ## 0.8707816
cor(subset_ec$Evap,subset_ec$eva_lin, method="pearson")                         # 0.6828481
cor(subset_ec$Evap,subset_ec$eva_pow, method="pearson")                         # 0.6724579


####  TABLE 4
### mean root Irgason
mean(sqrt((eva_day$eva_ec - eva_day$eva_sh_ir)^2), na.rm=TRUE)                ## 2.052012
mean(sqrt((eva_day$Evap - eva_day$eva_od_ir)^2), na.rm=TRUE)                  ## 2.200751
mean(sqrt((eva_day$Evap - eva_day$eva_pe_ir)^2), na.rm=TRUE)                  ## 1.800509
mean(sqrt((eva_day$Evap - eva_day$eva_dp_ir)^2), na.rm=TRUE)                  ## 1.320616
mean(sqrt((eva_day$Evap - eva_day$eva_BA_irg)^2), na.rm=TRUE)                 ## 1.043484

### Maitri
mean(sqrt((eva_day$Evap - eva_day$eva_sh_mai)^2), na.rm=TRUE)                 ## 2.101025
mean(sqrt((eva_day$Evap - eva_day$eva_od_mai)^2), na.rm=TRUE)                 ## 2.203179
mean(sqrt((eva_day$Evap - eva_day$eva_pe_mai)^2), na.rm=TRUE)                 ## 1.849679
mean(sqrt((eva_day$Evap - eva_day$eva_dp_mai)^2), na.rm=TRUE)                 ## 1.382076
mean(sqrt((eva_day$Evap - eva_day$eva_lin)^2), na.rm=TRUE)                    ## 1.002889  
mean(sqrt((eva_day$Evap - eva_day$eva_BA_mai)^2), na.rm=TRUE)                 ## ??

mean(sqrt((eva_day$Evap - eva_day$eva_pow)^2), na.rm=TRUE)                    ## 0.8505855
###########################################################

### Pearson correlation coefficent
### irgason
cor(eva_day$Evap,eva_day$eva_sh_ir, method="pearson")                         # [1] 0.5534304, SH
cor(eva_day$Evap,eva_day$eva_od_ir, method="pearson")                         # [1] 0.4012656, OD
cor(eva_day$Evap,eva_day$eva_dp_ir, method="pearson")                         # [1] 0.4255161, DP
cor(eva_day$Evap,eva_day$eva_pe_ir, method="pearson")                         # [1] 0.3538214, PE
cor(eva_day$Evap,eva_day$eva_BA_irg, method="pearson")                        # [1] 0.3538214, Bulk-aerodynamic

### Maitri
cor(eva_day$Evap,eva_day$eva_sh_mai, method="pearson")                        #[1] 0.5479032
cor(eva_day$Evap,eva_day$eva_od_mai, method="pearson")                        # [1] 0.4431134
cor(eva_day$Evap,eva_day$eva_dp_mai, method="pearson")                        # [1] 0.4551627
cor(eva_day$Evap,eva_day$eva_pe_mai, method="pearson")                        # [1] 0.4024153
cor(eva_day$Evap,eva_day$eva_BA_mai, method="pearson")

cor(eva_day$eva_ec, eva_day$eva_pow, method="pearson",use="complete.obs")     # 0.5513543; a*w2^b
cor(eva_day$eva_ec, eva_day$eva_lin, method="pearson",use="complete.obs")     # 0.59;  a+b*w2
#########################################################################################

### s/sigma criterio, (Popov,  1979, p. 58) #############################################
m1 <- mean(eva_day$eva_ec)                                   # mean evaporation, EC method
l1 <- length(eva_day$eva_ec)                                  # length of time series
sigma <- sqrt(sum((eva_day$eva_ec-m1)**2)/l1)                 

s<-sqrt(sum((eva_day$eva_BA_irg-eva_day$eva_ec)**2)/(l1-2))             ## Bulk method + irgason ### 1.1
s/sigma
s<-sqrt(sum((eva_day$eva_BA_mai-eva_day$eva_ec)**2)/(l1-2))             ## Bulk method + maitri ### ??
s/sigma

s<-sqrt(sum((eva_day$eva_od_mai-eva_day$eva_ec)**2)/(l1-2) )            ## Odrova + Maitri ### 2.394617
s/sigma
s<-sqrt(sum((eva_day$eva_od_ir-eva_day$eva_ec)**2)/(l1-2) )             ## Odrova +IR ### 2.413546
s/sigma

s<-sqrt(sum((eva_day$eva_pe_mai-eva_day$eva_ec)**2)/(l1-2))             ## Penmann + Maitri ### 2.062854
s/sigma
s<-sqrt(sum((eva_day$eva_pe_ir-eva_day$eva_ec)**2)/(l1-2))              ## Penmann + Maitri ### 2.049205
s/sigma

s<-sqrt(sum((eva_day$eva_dp_ir-eva_day$eva_ec)**2)/(l1-2))              ## Doorenboss + Irgason ### 1.611335
s/sigma
s<-sqrt(sum((eva_day$eva_dp_mai-eva_day$eva_ec)**2)/(l1-2))             ## Doorenboss + Maitri ### 1.622903
s/sigma

s<-sqrt(sum((eva_day$eva_sh_ir-eva_day$eva_ec)**2)/(l1-2))              ## Shuttleworth, 1993 + Irgason ### 2.253022
s/sigma
s<-sqrt(sum((eva_day$eva_sh_mai-eva_day$eva_ec)**2)/(l1-2))             ## Shuttleworth, 1993 + Maitri ### 2.278073
s/sigma

s<-sqrt(sum((eva_day$eva_lin-eva_day$eva_ec)**2)/(l1-2))                ## a+bw2 ### 1.306494
s/sigma
s<-sqrt(sum((eva_day$eva_pow-eva_day$eva_ec)**2)/(l1-2))                ## aw2^b ### 1.155177
s/sigma
##################################################################################################################


########################## FIGURES ###############################################################################
###################################################################################################################

############### fig. 2 wind speed at Novo, BAS archive 
path<-"/home/shevnina/Manuscripts/2022/Antarctica_evaporation/Gryosphere2021/new_supplements/"
setwd(path)
infile<-"89512n_wind_dec.txt"                                     # To read table with data from file: 89512n_wind_dec.txt or 89512n_wind_jan.txt (BAS, Reader old).
wdspt <- read.table(infile, header=T, sep=" ")
m_wsp<-mean(wdspt$wsd)*0.5144 # To calculate the mean wind speed (ms-1)
wdspt$awsp<-c(wdspt$wsd*0.5144-m_wsp) # To caculate anomaly of wind speed

# to reclass of wind speed anomalies
#Levels: (-100,-10] (-10,-5] (-5,0] (0,5] (5,10] (10,15] (15,23] (23,100]
#Level_labels: 1 2 3 4 5 6 7 8
wdspt$lawsp<-cut(wdspt$awsp, breaks=c(-25,-10,-5,0,5,10,25))
# to reclass of wind direction
#Levels: [0,10] (10,20] (20,30] (30,40] (40,50] (50,60] (60,70] ... (350,360]
wdbreaks<-seq(0,360, by=10)

#Level_labels:10 20 30 40 50 60 70 80 90 100 110 120 130 140 150 160 170 ... 360
wdlabels<-seq(10,360, by=10)
wdspt$lwd<-cut(wdspt$wd,breaks=wdbreaks,labels=c(wdlabels),include.lowest=T)

# to calculate the table for the figure: x-value wd, y-value class of aspt
gdata<-table(wdspt$lawsp,wdspt$lwd)

# to save plot in external file: name for the output file
#pdf("Fig2a.pdf")
pdf("Fig2new.pdf")
barplot(gdata, xlab='Wind Direction, degree', ylab='Number of cases', ylim=c(0,800), col=c('grey','blue','lightblue','orange','red','darkred','black'), legend=rownames(gdata), args.legend = list(title="Anomaly of wind speed", x="topright", cex=.8))
dev.off()


####################################################################################################################
# figure 3 c in the revised manuscript: the footprint of the Irgason

plot(dat1$Timestamp_UTC, dat1$XR90, col="red", xlab="2018", ylab="", ylim=c(0,200), type="l", xaxt="n")
lines(dat1$Timestamp_UTC, dat1$Xmax, col="blue", xlab="", ylab="", type="l", xaxt="n")
axis.POSIXct(1, at = seq(min(dat1$Timestamp_UTC), max(dat1$Timestamp_UTC), "5 day"), labels = TRUE, format="%m/%d")
grid()
mtext("Footprint length, m",side=2,line=2.5)


plot(eva_day$newTS, eva_day$diff_EC_Bulk_m, type="h", xlab="2018", ylab="EEC-Em, mm day-1")
points(less6$newTS, less6$diff_EC_Bulk_m, col="black", pch=20)

# b

plot(irg_day$newTS, irg_day$WS, xlab="2018", ylab="", ylim=c(min(irg_day$WS),max(irg_day$WS)), axes=FALSE, type="b", col="red")
mtext("m per sec",side=2,line=2.5)
axis(2,  ylim=c(20,80), col="black",col.axis="black",las=1)
axis.Date(1, at=seq(as.Date("2018/01/01"), as.Date("2018/02/08"),by="5 day"), format="%m/%d", cex.lab=1.5)
grid()
box()


########################################################################################################################################
### Figure 4 in the revised version: data
plot(hobo_day$newTS, hobo_day$TW_mean, xlab="2018", ylab="", ylim=c(-10,10), axes=FALSE, type="l", col="blue")
lines(meteo_ms$newTS, meteo_ms$AT, xlab="", ylab="", col="black", pch=20)
lines(ibut24hour$newTS, ibut24hour$TW_mean, col="red")
mtext("\u00B0C",side=2,line=2.5) 
axis(2,  ylim=c(20,80), col="black",col.axis="black",las=1)
axis.Date(1, at=seq(as.Date("2018/01/01"), as.Date("2018/02/08"), by="11 day"), format="%m/%d", cex.lab=1.5)
grid()
box()
abline(h=0, col="black")
#########################################################################################################################################

#### figure 5 ##########################################################################
#### for each method one graph##########################################################
plot(resEC$Evap, evap_BA$Evap, col="black", pch=20, type="p", xlim=c(0,5), ylim=c(0, 5), xlab="EEC, [mm day-1]", ylab="Bulk aerodynamic, [mm day-1]")
points(resEC$Evap, evap_BA_m$Evap_m, col="red", pch=0)
abline(0,1, col="grey", lty=2) 
abline(lm(evap_BA$Evap~resEC$Evap), col="black")
abline(lm(evap_BA_m$Evap_m~resEC$Evap), col="red")
grid()

m1<-summary(lm(evap_BA$Evap~resEC$Evap))
m2<-summary(lm(evap_BA_m$Evap_m~resEC$Evap))

t<-c("R2 =")
r1<-as.character(round(m1$r.squared, digits=2))
r2<-as.character(round(m2$r.squared, digits=2))

text(1,4.5,paste(t,r1), col="black")
text(1,4,paste(t,r2), col="red")

##############################################
# figure 6
plot(irg_day$newTS, irg_day$eva, xlab="2018", ylab="", ylim=c(min(evap_BA_m$Evap_m),max(irg_day$eva)), axes=FALSE, type="b", col="black", pch=20)
mtext("mm day-1",side=2,line=2.5) 
axis(2,  ylim=c(20,80), col="black",col.axis="black",las=1)
axis.Date(1, at=seq(as.Date("2018/01/01"), as.Date("2018/02/08"),by="11 day"), format="%m/%d", cex.lab=1.5)
grid()
box()
lines(irg_day$newTS, evap_BA_m$Evap, col="red", type="b", pch=20) ## results after bulk-transer method + Maitri site
#lines(irg_day$newTS, evap_BA$Evap, col="black") ## Bulk-transfer + Irgason



#################################################
# figure 7 
#plot(eva_day$Evap, pred_eva, col="black", pch=20, type="p", xlim=c(0,6), ylim=c(0, 6), xlab="EEC", ylab="Em")
#abline(lm(pred_eva~eva_day$Evap))
#abline(0,1, col="red", lty=2)             ######## 45 degree line
#grid()
#box()

plot(eva_day$newTS, eva_day$eva_ec, xlab="2018", ylab="", ylim=c(0,7), axes=FALSE, type="b", pch=20, col="black")
mtext("E, mm",side=2,line=2.5) 
#abline(v=as.Date("2018-01-19"), col="grey")
axis(2,  ylim=c(20,80), col="black",col.axis="black",las=1)
axis.Date(1, at=seq(as.Date("2018/01/01"), as.Date("2018/02/08"),by="11 day"), format="%m/%d", cex.lab=1.5)
grid()
box()
lines(eva_day$newT, eva_day$eva_lin, col="red", lty = "dotdash")                              ## fitted with a+b*w2, Maitri site
lines(eva_day$newT, eva_day$eva_BA_mai, col="blue", lty = "dotdash")                          ## bulk-aerodynamic, Maitri site
#lines(subset_ec$newTS, subset_ec$eva_lin, col="orange")
